from setuptools import setup

setup(name='lg_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['lg_distributions'],
      author = 'lenz',
      email = 'lbgarcia4@up.edu.ph',
      zip_safe=False)
